package com.management.platform.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.management.platform.entity.Report;
import com.management.platform.mapper.ReportMapper;
import com.management.platform.service.ReportService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.management.platform.util.HttpRespMsg;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 吴涛涛
 * @since 2019-12-31
 */
@Service
public class ReportServiceImpl extends ServiceImpl<ReportMapper, Report> implements ReportService {

    @Resource
    private ReportMapper reportMapper;


    /**
     * 获取报告列表
     * 可以基于报告者id 报告种类 报告日期来筛选
     *
     * @param creatorId
     * @param reportType
     * @param startDate
     * @param endDate
     * @return
     */
    @Override
    public HttpRespMsg getReportList(Integer pageIndex, Integer pageSize, Integer creatorId, Integer reportType,
                                     String startDate, String endDate) {
        HttpRespMsg httpRespMsg = new HttpRespMsg();
        QueryWrapper<Report> queryWrapper = new QueryWrapper<>();
        if (creatorId != null) {
            queryWrapper.eq("creator_id", creatorId);
        }
        if (reportType != null) {
            queryWrapper.eq("report_type", reportType);
        }
        if (startDate != null && endDate != null) {
            queryWrapper.between("create_date", startDate, endDate);
        }
        httpRespMsg.data = reportMapper.selectPage(new Page<>(pageIndex, pageSize), new QueryWrapper<>());
        return httpRespMsg;
    }

    /**
     * 基于id修改报告内容
     *
     * @param reportId
     * @param content
     * @return
     */
    @Override
    public HttpRespMsg editReport(Integer reportId, String content) {
        HttpRespMsg httpRespMsg = new HttpRespMsg();
        Report report = reportMapper.selectById(reportId);
        if (report != null) {
            report.setContent(content);
            Integer impactedRows = reportMapper.updateById(report);
            if (impactedRows == 0) {
                httpRespMsg.setError("操作失败");
            }
        } else {
            httpRespMsg.setError("未找到相应报告");
        }
        return httpRespMsg;
    }

    /**
     * 基于id删除报告
     *
     * @param reportId
     * @return
     */
    @Override
    public HttpRespMsg deleteReport(Integer reportId) {
        HttpRespMsg httpRespMsg = new HttpRespMsg();
        Integer impactedRows = reportMapper.deleteById(reportId);
        if (impactedRows == 0) {
            httpRespMsg.setError("操作失败");
        }
        return httpRespMsg;
    }
}
